@@ -3,19 +3,23 @@ package Net::DNS::Resolver::Unbound;
 use strict;
 use warnings;
 use integer;
-use Net::DNS;
 
-use constant OS_SPEC => defined eval "require Net::DNS::Resolver::$^O";	## no critic
-use constant OS_CONF => join '::', 'Net::DNS::Resolver', OS_SPEC ? $^O : 'UNIX';
-use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
+use Net::DNS;
+use base qw(Net::DNS::Resolver::Base DynaLoader);
+
+use constant OS_SPEC => "Net::DNS::Resolver::$^O";
+use constant OS_UNIX => "Net::DNS::Resolver::UNIX";
+use constant OS_CONF => grep eval "require $_", OS_SPEC, OS_UNIX;	## no critic
+use base (OS_CONF)[0];			## backward compatibility only
 
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.31';
+	$VERSION = '1.33';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
+
 use constant UB_VERSION => scalar eval {
 	my $version = Net::DNS::Resolver::libunbound->VERSION();
 	my ( $major, $minor, $minimus ) = split /\D/, $version;
@@ -100,6 +104,7 @@ sub import {
 	my ( $class, @argument ) = @_;
 	my $register = grep {/^-register$/i} @argument;
 	@Net::DNS::Resolver::ISA = $class if $register;
+	return;
 }
 
 
@@ -141,15 +146,15 @@ The following keywords are recognised in resolver configuration files:
 
 =over
 
-=item B<nameserver> address
+=item B<nameserver>
 
 IP address of a name server that the resolver should query.
 
-=item B<domain> localdomain
+=item B<domain>
 
 The domain suffix to be appended to a short non-absolute name.
 
-=item B<search> domain ...
+=item B<search>
 
 A space-separated list of domains in the desired search path.
 
@@ -182,16 +187,22 @@ sub new {
 
 =head2 nameservers
 
-	my $dnssec_resolver = Net::DNS::Resolver::Unbound->new(
+	my $DNSSEC_resolver = Net::DNS::Resolver::Unbound->new(
 		nameservers => [],	# override /etc/resolv.conf
 		add_ta_file => '/var/lib/unbound/root.key'
 		);
 
+	my $DNSSEC_stub = Net::DNS::Resolver::Unbound->new(
+		nameservers => ['8.8.8.8', '1.1.1.1'],
+		add_ta_file => '/var/lib/unbound/root.key'
+		);
+
 	my $DoT_resolver = Net::DNS::Resolver::Unbound->new(
 		nameserver => '2606:4700:4700::1111@853#cloudflare-dns.com',
 		nameserver => '1.1.1.1@853#cloudflare-dns.com',
 		nameserver => '2001:4860:4860::8888@853#dns.google',
 		nameserver => '8.8.8.8@853#dns.google',
+		add_ta_file => '/var/lib/unbound/root.key',
 		option	=> ['tls-cert-bundle' => '/etc/ssl/cert.pem'],
 		set_tls	=> 1
 		);
@@ -200,7 +211,7 @@ sub new {
 	@nameservers = $resolver->nameservers;
 
 By default, DNS queries are sent to the IP addresses listed in
-/etc/resolv.conf or similar platform-specific sources.
+F</etc/resolv.conf> or similar platform-specific sources.
 
 =cut
 
@@ -219,7 +230,7 @@ sub nameservers {
 	return;
 }
 
-sub nameserver { &nameservers; }
+sub nameserver { return &nameservers }
 
 
 =head2 search, query, send, bgsend, bgbusy, bgread
@@ -367,7 +378,7 @@ sub set_stub {
 Extract nameserver list from resolv.conf(5) format configuration file.
 Any domain, searchlist, ndots or other settings are ignored.
 
-Note that Net::DNS builds its own nameserver list using /etc/resolv.conf
+Note that Net::DNS builds its own nameserver list using F</etc/resolv.conf>
 or other platform-specific sources.
 
 =cut
@@ -382,7 +393,7 @@ sub resolv_conf {
 
 	$resolver->hosts( 'filename' );
 
-Read list of hosts from the filename given, usually "/etc/hosts".
+Read list of hosts from the filename given, usually F</etc/hosts>.
 These addresses are not flagged as DNSSEC secure when queried.
 
 =cut
